Retrieve metadata on the structure and available variables for all available
data sets or the information available in a specific dataset based on its ID.
Usage
nomis_data_info(id, tidy = FALSE)
Arguments
id
Dataset ID. If empty, returns data on all available datasets.
If the ID of a dataset, returns metadata for that particular dataset.
tidy
If TRUE, converts tibble names to snakecase.
Value
A tibble with all available datasets and their metadata.
# NOT RUN {# Get info on all datasetsx <- nomis_data_info()
tibble::glimpse(x)
# Get info on a particular datasety <- nomis_data_info("NM_1658_1")
tibble::glimpse(y)
# }# NOT RUN {# }